@@ -1,4 +1,5 @@
 #include "cfl_browser.h"
+#include "cfl_lock.hpp"
 
 #include <FL/Fl.H>
 #include <FL/Fl_Browser.H>
@@ -11,7 +12,8 @@
 
 #define BROWSER_DEFINE(widget)                                                                     \
     int widget##_value(widget *self) {                                                             \
-        return self->value();                                                                      \
+        LOCK(int ret = self->value());                                                             \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_remove(widget *self, int line) {                                                 \
         LOCK(self->remove(line);)                                                                  \
@@ -32,18 +34,20 @@
         LOCK(self->clear();)                                                                       \
     }                                                                                              \
     int widget##_size(const widget *self) {                                                        \
-        return self->size();                                                                       \
+        LOCK(auto ret = self->size());                                                             \
+        return ret;                                                                                \
     }                                                                                              \
     int widget##_select(widget *self, int line) {                                                  \
-        int ret = 0;                                                                               \
-        LOCK(ret = self->select(line));                                                            \
+        LOCK(auto ret = self->select(line));                                                       \
         return ret;                                                                                \
     }                                                                                              \
     int widget##_selected(const widget *self, int line) {                                          \
-        return self->selected(line);                                                               \
+        LOCK(auto ret = self->selected(line));                                                     \
+        return ret;                                                                                \
     }                                                                                              \
     const char *widget##_text(const widget *self, int line) {                                      \
-        return self->text(line);                                                                   \
+        LOCK(auto ret = self->text(line));                                                         \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_text(widget *self, int line, const char *newtext) {                          \
         LOCK(self->text(line, newtext);)                                                           \
@@ -52,7 +56,8 @@
         LOCK(self->load(file);)                                                                    \
     }                                                                                              \
     int widget##_text_size(widget *self) {                                                         \
-        return self->textsize();                                                                   \
+        LOCK(auto ret = self->textsize());                                                         \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_text_size(widget *self, int s) {                                             \
         LOCK(self->textsize(s);)                                                                   \
@@ -62,10 +67,11 @@
              else self->icon(line, ((Fl_Image *)icon)->copy()); delete old;)                       \
     }                                                                                              \
     void *widget##_icon(const widget *self, int line) {                                            \
-        auto temp = self->icon(line);                                                              \
+        LOCK(auto temp = self->icon(line));                                                        \
         if (!temp)                                                                                 \
             return NULL;                                                                           \
-        return ((Fl_Image *)temp)->copy();                                                         \
+        LOCK(auto ret = ((Fl_Image *)temp)->copy());                                               \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_remove_icon(widget *self, int l) {                                               \
         LOCK(self->remove_icon(l);)                                                                \
@@ -80,49 +86,57 @@
         LOCK(self->middleline(line);)                                                              \
     }                                                                                              \
     char widget##_format_char(const widget *self) {                                                \
-        return self->format_char();                                                                \
+        LOCK(auto ret = self->format_char());                                                      \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_format_char(widget *self, char c) {                                          \
         LOCK(self->format_char(c);)                                                                \
     }                                                                                              \
     char widget##_column_char(const widget *self) {                                                \
-        return self->column_char();                                                                \
+        LOCK(auto ret = self->column_char());                                                      \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_column_char(widget *self, char c) {                                          \
         LOCK(self->column_char(c);)                                                                \
     }                                                                                              \
     const int *widget##_column_widths(const widget *self) {                                        \
-        return self->column_widths();                                                              \
+        LOCK(auto ret = self->column_widths());                                                    \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_column_widths(widget *self, const int *arr) {                                \
         LOCK(self->column_widths(arr);)                                                            \
     }                                                                                              \
     int widget##_displayed(const widget *self, int line) {                                         \
-        return self->displayed(line);                                                              \
+        LOCK(auto ret = self->displayed(line));                                                    \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_make_visible(widget *self, int line) {                                           \
         LOCK(self->make_visible(line);)                                                            \
     }                                                                                              \
     int widget##_position(const widget *self) {                                                    \
-        return self->position();                                                                   \
+        LOCK(auto ret = self->position());                                                         \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_position(widget *self, int pos) {                                            \
         LOCK(self->position(pos);)                                                                 \
     }                                                                                              \
     int widget##_hposition(const widget *self) {                                                   \
-        return self->hposition();                                                                  \
+        LOCK(auto ret = self->hposition());                                                        \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_hposition(widget *self, int pos) {                                           \
         LOCK(self->hposition(pos);)                                                                \
     }                                                                                              \
     unsigned char widget##_has_scrollbar(const widget *self) {                                     \
-        return self->has_scrollbar();                                                              \
+        LOCK(auto ret = self->has_scrollbar());                                                    \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_has_scrollbar(widget *self, unsigned char mode) {                            \
         LOCK(self->has_scrollbar(mode);)                                                           \
     }                                                                                              \
     int widget##_scrollbar_size(const widget *self) {                                              \
-        return self->scrollbar_size();                                                             \
+        LOCK(auto ret = self->scrollbar_size());                                                   \
+        return ret;                                                                                \
     }                                                                                              \
     void widget##_set_scrollbar_size(widget *self, int newSize) {                                  \
         LOCK(self->scrollbar_size(newSize);)                                                       \
@@ -131,10 +145,12 @@
         LOCK(self->sort();)                                                                        \
     }                                                                                              \
     void *widget##_scrollbar(widget *self) {                                                       \
-        return &self->scrollbar;                                                                   \
+        LOCK(auto ret = &self->scrollbar);                                                         \
+        return ret;                                                                                \
     }                                                                                              \
     void *widget##_hscrollbar(widget *self) {                                                      \
-        return &self->hscrollbar;                                                                  \
+        LOCK(auto ret = &self->hscrollbar);                                                        \
+        return ret;                                                                                \
     }
 
 WIDGET_CLASS(Fl_Browser)
@@ -166,7 +182,8 @@ WIDGET_CLASS(Fl_File_Browser)
 WIDGET_DEFINE(Fl_File_Browser)
 
 unsigned Fl_File_Browser_iconsize(const Fl_File_Browser *self) {
-    return self->iconsize();
+    LOCK(auto ret = self->iconsize());
+    return ret;
 }
 
 void Fl_File_Browser_set_iconsize(Fl_File_Browser *self, unsigned s) {
@@ -178,11 +195,13 @@ void Fl_File_Browser_set_filter(Fl_File_Browser *self, const char *pattern) {
 }
 
 const char *Fl_File_Browser_filter(const Fl_File_Browser *self) {
-    return self->filter();
+    LOCK(auto ret = self->filter());
+    return ret;
 }
 
 int Fl_File_Browser_filetype(const Fl_File_Browser *self) {
-    return self->filetype();
+    LOCK(auto ret = self->filetype());
+    return ret;
 }
 
 void Fl_File_Browser_set_filetype(Fl_File_Browser *self, int t) {
@@ -196,14 +215,14 @@ WIDGET_CLASS(Fl_Check_Browser)
 WIDGET_DEFINE(Fl_Check_Browser)
 
 int Fl_Check_Browser_add(Fl_Check_Browser *self, const char *s, int b) {
-    int ret = 0;
-    LOCK(ret = self->add(s, b));
+
+    LOCK(auto ret = self->add(s, b));
     return ret;
 }
 
 int Fl_Check_Browser_remove(Fl_Check_Browser *self, int item) {
-    int ret = 0;
-    LOCK(ret = self->remove(item));
+
+    LOCK(auto ret = self->remove(item));
     return ret;
 }
 
@@ -212,15 +231,18 @@ void Fl_Check_Browser_clear(Fl_Check_Browser *self) {
 }
 
 int Fl_Check_Browser_nitems(const Fl_Check_Browser *self) {
-    return self->nitems();
+    LOCK(auto ret = self->nitems());
+    return ret;
 }
 
 int Fl_Check_Browser_nchecked(const Fl_Check_Browser *self) {
-    return self->nchecked();
+    LOCK(auto ret = self->nchecked());
+    return ret;
 }
 
 int Fl_Check_Browser_checked(const Fl_Check_Browser *self, int item) {
-    return self->checked(item);
+    LOCK(auto ret = self->checked(item));
+    return ret;
 }
 
 void Fl_Check_Browser_set_checked(Fl_Check_Browser *self, int item) {
@@ -236,11 +258,13 @@ void Fl_Check_Browser_check_none(Fl_Check_Browser *self) {
 }
 
 int Fl_Check_Browser_value(const Fl_Check_Browser *self) {
-    return self->value();
+    LOCK(auto ret = self->value());
+    return ret;
 }
 
 const char *Fl_Check_Browser_text(const Fl_Check_Browser *self, int item) {
-    return self->text(item);
+    LOCK(auto ret = self->text(item));
+    return ret;
 }
 
 void Fl_Check_Browser_set_text_color(Fl_Check_Browser *self, unsigned int c) {
@@ -248,7 +272,8 @@ void Fl_Check_Browser_set_text_color(Fl_Check_Browser *self, unsigned int c) {
 }
 
 unsigned int Fl_Check_Browser_text_color(Fl_Check_Browser *self) {
-    return self->textcolor();
+    LOCK(auto ret = self->textcolor());
+    return ret;
 }
 
 void Fl_Check_Browser_set_text_font(Fl_Check_Browser *self, int f) {
@@ -256,7 +281,8 @@ void Fl_Check_Browser_set_text_font(Fl_Check_Browser *self, int f) {
 }
 
 int Fl_Check_Browser_text_font(Fl_Check_Browser *self) {
-    return self->textfont();
+    LOCK(auto ret = self->textfont());
+    return ret;
 }
 
 void Fl_Check_Browser_set_text_size(Fl_Check_Browser *self, int s) {
@@ -264,11 +290,13 @@ void Fl_Check_Browser_set_text_size(Fl_Check_Browser *self, int s) {
 }
 
 int Fl_Check_Browser_text_size(Fl_Check_Browser *self) {
-    return self->textsize();
+    LOCK(auto ret = self->textsize());
+    return ret;
 }
 
 int Fl_Check_Browser_position(const Fl_Check_Browser *self) {
-    return self->position();
+    LOCK(auto ret = self->position());
+    return ret;
 }
 
 void Fl_Check_Browser_set_position(Fl_Check_Browser *self, int pos) {
@@ -276,7 +304,8 @@ void Fl_Check_Browser_set_position(Fl_Check_Browser *self, int pos) {
 }
 
 int Fl_Check_Browser_hposition(const Fl_Check_Browser *self) {
-    return self->hposition();
+    LOCK(auto ret = self->hposition());
+    return ret;
 }
 
 void Fl_Check_Browser_set_hposition(Fl_Check_Browser *self, int pos) {
@@ -284,7 +313,8 @@ void Fl_Check_Browser_set_hposition(Fl_Check_Browser *self, int pos) {
 }
 
 unsigned char Fl_Check_Browser_has_scrollbar(const Fl_Check_Browser *self) {
-    return self->has_scrollbar();
+    LOCK(auto ret = self->has_scrollbar());
+    return ret;
 }
 
 void Fl_Check_Browser_set_has_scrollbar(Fl_Check_Browser *self, unsigned char mode) {
@@ -292,7 +322,8 @@ void Fl_Check_Browser_set_has_scrollbar(Fl_Check_Browser *self, unsigned char mo
 }
 
 int Fl_Check_Browser_scrollbar_size(const Fl_Check_Browser *self) {
-    return self->scrollbar_size();
+    LOCK(auto ret = self->scrollbar_size());
+    return ret;
 }
 
 void Fl_Check_Browser_set_scrollbar_size(Fl_Check_Browser *self, int newSize) {
@@ -304,9 +335,11 @@ void Fl_Check_Browser_sort(Fl_Check_Browser *self) {
 }
 
 const void *Fl_Check_Browser_scrollbar(const Fl_Check_Browser *self) {
-    return &self->scrollbar;
+    LOCK(auto ret = &self->scrollbar);
+    return ret;
 }
 
 const void *Fl_Check_Browser_hscrollbar(const Fl_Check_Browser *self) {
-    return &self->hscrollbar;
+    LOCK(auto ret = &self->hscrollbar);
+    return ret;
 }
